==> nextcloud-app-deck-1%3A0.6.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/uk.js <==
OC.L10N.register(
    "deck",
    {
    "Hours" : "Годин",
    "Minutes" : "Хвилин",
    "Deck" : "Колода",
    "Finished" : "Завершено",
    "To review" : "На перегляд",
    "Action needed" : "Потребує дій",
    "Later" : "Пізніше",
    "Add a new stack" : "Додати нову купу",
    "Show archived cards" : "Показати архівні картки",
    "Hide archived cards" : "Приховати архівні картки",
    "All Boards" : "Всі дошки",
    "Archived boards" : "Архівовані дошки",
    "Enter a card title" : "Введіть заголовок картки",
    "Sharing" : "Поділитись",
    "Tags" : "Теги",
    "Select users or groups to share with" : "Оберіть користувача або групу щоб поділитись",
    "No matching user or group found." : "Користувачів або груп не знайдено",
    "Edit" : "Редагувати",
    "Share" : "Поділитись",
    "Manage" : "Керувати",
    "Discard share" : "Відмінити спільне використання",
    "Create a new tag" : "Створити новий тег",
    "Title" : "Заголовок",
    "Members" : "Учасники",
    "More actions" : "Більше дій",
    "Edit board" : "Змінити дошку",
    "Archive board" : "Архівувати дошку",
    "Unarchive board" : "Розархівувати дошку",
    "Delete board" : "Видалити дошку",
    "Create new board" : "Створити нову дошку",
    "New board title" : "Новий заголовок дошки",
    "by" : "від",
    "Modified:" : "Змінено:",
    "Created:" : "Створено:",
    "Due date" : "Протягом",
    "Click to set" : "Клацніть для налаштування",
    "Remove due date" : "Видалити до",
    "Description" : "Опис",
    "Saved" : "Збережено",
    "Formatting help" : "Форматування довідки",
    "Add a card description…" : "Додати опис дошки",
    "Shared boards" : "Спільні дошки",
    "Move board to archive" : "Перемістити до архіву",
    "Create a new board" : "Створити нову дошку"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-app-deck-1%3A0.8.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/uk.js <==
OC.L10N.register(
    "deck",
    {
    "Hours" : "Годин",
    "Minutes" : "Хвилин",
    "File already exists" : "Файл вже існує",
    "Deck" : "Колода",
    "Personal" : "Особисте",
    "Finished" : "Завершено",
    "To review" : "На перегляд",
    "Action needed" : "Потребує дій",
    "Later" : "Пізніше",
    "Done" : "Готово",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір вивантаженого файлу перевищує директиву MAX_FILE_SIZE вказану в HTML формі",
    "No file was uploaded" : "Не вивантажено жодного файлу",
    "Missing a temporary folder" : "Відсутній тимчасовий каталог",
    "Add a new stack" : "Додати нову купу",
    "Show archived cards" : "Показати архівні картки",
    "Hide archived cards" : "Приховати архівні картки",
    "All Boards" : "Всі дошки",
    "Archived boards" : "Архівовані дошки",
    "Actions" : "Дії",
    "Assign card to me" : "Прив'язати картку до мене",
    "Unassign card from me" : "Відв'язати картку від мене",
    "Archive card" : "Архівувати картку",
    "Delete card" : "Видалити картку",
    "Enter a card title" : "Введіть заголовок картки",
    "Add card" : "Додати картку",
    "Close" : "Закрити",
    "Sharing" : "Поділитись",
    "Tags" : "Теги",
    "Select users or groups to share with" : "Оберіть користувача або групу щоб поділитись",
    "Group" : "Група",
    "Circle" : "Коло",
    "No matching user or group found." : "Користувачів або груп не знайдено",
    "Loading" : "Завантаження",
    "Edit" : "Редагувати",
    "Share" : "Поділитись",
    "Manage" : "Керувати",
    "Discard share" : "Відмінити спільне використання",
    "Create" : "Створити",
    "Create a new tag" : "Створити новий тег",
    "Title" : "Заголовок",
    "Members" : "Учасники",
    "More actions" : "Більше дій",
    "Edit board" : "Змінити дошку",
    "Archive board" : "Архівувати дошку",
    "Unarchive board" : "Розархівувати дошку",
    "Delete board" : "Видалити дошку",
    "Create new board" : "Створити нову дошку",
    "New board title" : "Новий заголовок дошки",
    "Cancel upload" : "Скасувати завантаження",
    "by" : "від",
    "Modified:" : "Змінено:",
    "Created:" : "Створено:",
    "Assign users" : "Додавання користувача",
    "Due date" : "Протягом",
    "Click to set" : "Клацніть для налаштування",
    "Remove due date" : "Видалити до",
    "Description" : "Опис",
    "Attachments" : "Вкладення",
    "Saved" : "Збережено",
    "Formatting help" : "Форматування довідки",
    "Add a card description…" : "Додати опис дошки",
    "Shared boards" : "Спільні дошки",
    "Move board to archive" : "Перемістити до архіву",
    "Create a new board" : "Створити нову дошку",
    "Settings" : "Налаштування"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
